**A Python module to interact with NASA's ADS that doesn't suck™**
==================================================================

[![Build Status](https://travis-ci.org/andycasey/ads-python.png?branch=master)](https://travis-ci.org/andycasey/ads-python)

If you're in research, then you pretty much _need_ NASA's ADS. It's tried, true, and people go crazy on the rare occasions when it goes down.



**Getting Started**

1. You'll need an API key from NASA ADS labs. You can apply for one [here](https://docs.google.com/spreadsheet/viewform?formkey=dFJZbHp1WERWU3hQVVJnZFJjbE05SGc6MQ#gid=0).

2. When you get your API key, save it to a file called ``~/.ads/dev_key`` or save it as an environment variable named ``ADS_DEV_KEY``

3. From a terminal type ``pip install ads`` (or [if you must](https://stackoverflow.com/questions/3220404/why-use-pip-over-easy-install), use ``easy_install ads``)

Happy Hacking!
